package vc.thinker.web;

import com.alibaba.fastjson.JSONObject;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import vc.thinker.config.interceptor.ServiceLimit;
import vc.thinker.response.SimpleResponse;
import vc.thinker.thirdpartyproxy.ProtocolType;
import vc.thinker.thirdpartyproxy.protocolimpls.centralAir.CentralAirProtocol;
import vc.thinker.thirdpartyproxy.protocolimpls.centralAir.dto.DataReportInfoDTO;
import vc.thinker.thirdpartyproxy.protocolimpls.centralAir.dto.DataReportParamDTO;
import vc.thinker.web.vo.TerminalDataReportVO;

import javax.validation.Valid;
import java.util.Objects;

/**
 * @author HeTongHao
 * @since 2022/8/9 15:56
 */
@Api
@Slf4j
@RequestMapping("/")
@RestController
@RequiredArgsConstructor
public class CentralAirController {

    @Autowired
    private CentralAirProtocol centralAirProtocol;


    @ApiOperation("设备数据上报接口")
    @PostMapping("data-report")
    @ServiceLimit(key = "data-report")
    public SimpleResponse dataReport(@RequestBody @Valid TerminalDataReportVO reportVO) {
        SimpleResponse simpleResponse = new SimpleResponse();
        simpleResponse.setCode("200");
        if (Objects.equals(reportVO.getProtocolCode(),ProtocolType.central_air_conditioning.getCode())){
            DataReportInfoDTO dto = DataReportInfoDTO.builder()
                    .protocolCode(reportVO.getProtocolCode())
                    .deviceAddress(reportVO.getDeviceAddress())
                    .timestamp(reportVO.getTimestamp())
                    .data(JSONObject.parseObject(JSONObject.toJSONString(reportVO.getData()), DataReportParamDTO.class))
                    .build();
            this.centralAirProtocol.dataReport(dto);
            simpleResponse.setSuccess(true);
            simpleResponse.setMessage("处理成功");
            return simpleResponse;
        }
        simpleResponse.setSuccess(false);
        simpleResponse.setMessage("处理失败");
        return simpleResponse;
    }

}
